changeset 183:fcef34d67ad9

- fixed small but silly bug for the objectedit plugin (forgot to complete renaming) @wenlin This should fix the "when the object is beach02 ..." issue - and some more ... ^^
author chewie@33b003aa-7bff-0310-803a-e67f0ece8222
date Thu, 19 Feb 2009 06:24:58 +0000
parents bcc93e17f978
children 32cc4bda190c
files clients/editor/plugins/mapeditor.py
diffstat 1 files changed, 6 insertions(+), 5 deletions(-) [+]
line wrap: on
line diff
--- a/clients/editor/plugins/mapeditor.py	Wed Feb 11 19:27:18 2009 +0000
+++ b/clients/editor/plugins/mapeditor.py	Thu Feb 19 06:24:58 2009 +0000
@@ -367,12 +367,12 @@
 			# project specific animation angles
 			try:
 				if self._objectedit_rotations is not None:
 #				print "available angles: ", self._offsetedit_rotations
 					rotation_prev = i.getRotation()
 #				print "previous rotation: ", rotation_prev
-					length = len(self._offsetedit_rotations)
+					length = len(self._objectedit_rotations)
 #				print "length: ", length
-					index = self._offsetedit_rotations.index( str(rotation_prev) )
+					index = self._objectedit_rotations.index( str(rotation_prev) )
 #				print "index, old: ", index
 					if index < length - 1:
 						index += 1
@@ -382,11 +382,12 @@
 						index = 0
 #				print "index, new: ", index
 					
-					i.setRotation( int(self._offsetedit_rotations[index]) )
-#				print "new rotation: ", self._offsetedit_rotations[index]
+					i.setRotation( int(self._objectedit_rotations[index]) )
+#				print "new rotation: ", self._objectedit_rotations[index]
 			except:
 				# Fallback
 				i.setRotation((i.getRotation() + 90) % 360)
+			
 # end FIXME
 # end edit c
@@ -367,12 +367,12 @@
 			try:
 				if self._objectedit_rotations is not None:
-#				print "available angles: ", self._offsetedit_rotations
+#				print "available angles: ", self._objectedit_rotations
 					rotation_prev = i.getRotation()
 #				print "previous rotation: ", rotation_prev